Name:       libbson
Version:    1.3.5
Release:    6%{?dist}
Summary:    Building, parsing, and iterating BSON documents
Group:      System Environment/Libraries
## Installed:
# COPYING:                          ASL 2.0
# src/bson/b64_ntop.h:              ISC and MIT
# src/bson/b64_pton.h:              ISC and MIT
# src/bson/bson-md5.h:              zlib
# src/yajl/yajl_alloc.h:            ISC
# doc/man/bson_iter_symbol.3:       GFDL
## Not installed:
# configure:                        FSFUL
# aclocal.m4:                       FSFULLR
# Makefile.in:                      FSFULLR
# build/autotools/depcomp:          GPLv2+ with exceptions
# build/autotools/ltmain.sh:        GPLv2+ with exceptions
# build/autotools/m4/ax_pthread.m4  GPLv3+ with exception
# build/autotools/install-sh:       MIT and Public Domain
# doc/html/jquery.js:               (MIT or GPLv2) and (MIT, BSD GPL)
# doc/html/jquery.syntax.js:        MIT
# doc/mallard2man.py:               GPLv3+
# src/bson/bson-stdint-win32.h:     BSD
License:    ASL 2.0 and ISC and MIT and zlib
URL:        https://github.com/mongodb/%{name}
Source0:    %{url}/releases/download/%{version}/%{name}-%{version}.tar.gz
# Do not install COPYING, install ChangeLog, distribution specific
Patch0:     %{name}-1.3.1-Install-documentation-according-to-guidelines.patch
# Fix buffer overrun/read in bson_strndup, in 1.4.0
Patch1:     %{name}-1.3.0-CDRIVER-1403-fixed-buffer-overrun-read-in-bson_strnd.patch
# Do not panic on allocating zero bytes,
# <https://jira.mongodb.org/browse/CDRIVER-1579>, fixed after 1.5.0-rc1
Patch2:     %{name}-1.5.0-rc1-CDRIVER-1579-bson_malloc-can-abort-on-success.patch
# 1/2 Fix CVE-2017-14227 (a crash when parsing an empty code string of
# a codewscope type), bug #1494402,
# <https://jira.mongodb.org/browse/CDRIVER-2269>
Patch3:     %{name}-1.3.5-CDRIVER-2269-Check-for-zero-string-length-in-codewsc.patch
# 2/2 Fix CVE-2017-14227 (a crash when parsing an empty code string of
# a codewscope type, bug #1494402,
# <https://jira.mongodb.org/browse/CDRIVER-2269>
Patch4:     %{name}-1.3.5-CDRIVER-2269-Fix-codewscope-test.patch
# Fix validating dbpointer when parsing BSON, CDRIVER-2339, in 1.9.0
Patch5:     %{name}-1.3.5-CDRIVER-2339-fix-dbpointer-string-validation.patch
# Fix handling UTF-8 two-byte NUL character, CDRIVER-2401, in 1.9.0
Patch6:     %{name}-1.3.5-CDRIVER-2401-check-for-UTF-8-two-byte-NULL.patch
# Fix CVE-2018-16790 (heap-based buffer over-read in
# _bson_iter_next_internal()), bug #1627925, fixed in mongo-c-driver-1.14.0
Patch7:     %{name}-1.3.5-Fix-for-CVE-2018-16790-Verify-bounds-before-binary-l.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc
# git because of binary CDRIVER-2269-Check-for-zero-string-length-in-codewsc.patch
# and Fix-for-CVE-2018-16790-Verify-bounds-before-binary-l.patch
BuildRequires:  git-core
BuildRequires:  libtool
BuildRequires:  python
# Modified yajl-2.0.4 is bundled, waiting on yajl upstream to merge libbson's
# changes, <https://github.com/lloyd/yajl/issues/161>,
# <https://jira.mongodb.org/browse/CDRIVER-601>, bug #1215182
Provides:       bundled(yajl) = 2.0.4

%description
This is a library providing useful routines related to building, parsing,
and iterating BSON documents <http://bsonspec.org/>.

%package devel
Summary:    Development files for %{name}
Group:      Development/Libraries
License:    ASL 2.0 and GFDL
Requires:   %{name}%{?_isa} = %{version}-%{release}
# gcc for standard library header files
Requires:   gcc%{?_isa}
Requires:   pkgconfig

%description devel
This package contains libraries and header files needed for developing
applications that use %{name}.

%prep
# git format for CDRIVER-2269-Check-for-zero-string-length-in-codewsc.patch
%autosetup -S git -n %{name}-%{version}
# Generate build scripts from sources
autoreconf --force --install

%build
%configure \
    --disable-coverage \
    --disable-debug \
    --disable-debug-symbols \
    --enable-extra-align \
    --disable-hardening \
    --disable-html-docs \
    --enable-ld-version-script \
    --disable-lto \
    --disable-maintainer-flags \
    --enable-man-pages \
    --disable-optimizations \
    --enable-shared \
    --disable-silent-rules \
    --disable-static \
    --disable-yelp
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot}
find %{buildroot} -name '*.la' -exec rm -f '{}' +
# Move ambiguously named manual pages into package-specific directory
# <https://jira.mongodb.org/browse/CDRIVER-1039>
install -d -m 0755 %{buildroot}%{_docdir}/%{name}-devel
for P in clock creating endianness errors index installing json memory \
        oid parsing performance threading utf8 version; do
    mv %{buildroot}%{_mandir}/man3/"$P".3 %{buildroot}%{_docdir}/%{name}-devel
done
# Install examples here because it's forbidden to use relative %%doc with
# installing into %%_pkgdocdir
install -d -m 0755 %{buildroot}%{_docdir}/%{name}-devel/examples
install -m 0644 -t %{buildroot}%{_docdir}/%{name}-devel/examples examples/*.c

%check
make %{?_smp_mflags} check

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%license COPYING
# AUTHORS is empty, README etc. are installed by "make install"
%{_docdir}/%{name}
%{_libdir}/*.so.*

%files devel
%{_docdir}/%{name}-devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*
%{_mandir}/man3/*

%changelog
* Tue Sep 18 2018 Petr Pisar <ppisar@redhat.com> - 1.3.5-6
- Fix CVE-2018-16790 (heap-based buffer over-read in
  _bson_iter_next_internal()) (bug #1627925)

* Thu Dec 21 2017 Petr Pisar <ppisar@redhat.com> - 1.3.5-5
- Fix validating dbpointer when parsing BSON (CDRIVER-2339)
- Fix handling UTF-8 two-byte NUL character (CDRIVER-2401)

* Fri Sep 15 2017 Petr Pisar <ppisar@redhat.com> - 1.3.5-4
- Fix CVE-2017-14227 (a crash when parsing an empty code string of
  a codewscope type) (bug #1494402)

* Thu Oct 13 2016 Petr Pisar <ppisar@redhat.com> - 1.3.5-3
- Do not panic on allocating zero bytes

* Mon Aug 29 2016 Petr Pisar <ppisar@redhat.com> - 1.3.5-2
- Fix buffer overrun/read in bson_strndup

* Thu Mar 31 2016 Petr Pisar <ppisar@redhat.com> - 1.3.5-1
- 1.3.5 bump

* Tue Mar 15 2016 Petr Pisar <ppisar@redhat.com> - 1.3.4-1
- 1.3.4 bump

* Mon Feb 15 2016 Petr Pisar <ppisar@redhat.com> - 1.3.3-1
- 1.3.3 bump

* Fri Jan 22 2016 Petr Pisar <ppisar@redhat.com> - 1.3.1-1
- Packaged
